var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { DocumentLabelerConstants } from "documentLabeler/constants/DocumentLabelerConstants";
import { MockDocumentLabelerData } from "documentLabeler/MockDocumentLabelerData.stories";
import { FieldsPanelDisplayUtils } from "documentLabeler/common/util/FieldsPanelDisplayUtils";
var textField = MockDocumentLabelerData.labels.fields[0];
var checkboxField = MockDocumentLabelerData.labels.fields[2];
var signatureField = MockDocumentLabelerData.labels.fields[3];
describe('getTextValueFromField', function () {
    /** Text Field Tests */
    it('should return the text override value if a text override is specified', function () {
        var override = 'Override';
        var field = __assign(__assign({}, textField), { textOverride: override });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(override);
    });
    it('should return the joined blocks text if blocks are specified', function () {
        var expectedOutput = 'ATS Automation Tooling Systems Inc. 27-Apr-2018';
        var field = __assign(__assign({}, textField), { blocks: [MockDocumentLabelerData.wordBlocks[0], MockDocumentLabelerData.wordBlocks[1]] });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
    it('should return the region selected string if a region is specified', function () {
        var expectedOutput = DocumentLabelerConstants.REGION_SELECTED;
        var field = __assign(__assign({}, textField), { blocks: [], region: signatureField.region });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
    it('should return empty for an unlabeled field', function () {
        var expectedOutput = DocumentLabelerConstants.EMPTY;
        var field = __assign(__assign({}, textField), { blocks: [] });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
    /** Checkbox Field Tests */
    it('should return the text override value if a text override is specified', function () {
        var override = 'Override';
        var field = __assign(__assign({}, checkboxField), { textOverride: override });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(override);
    });
    it('should return selected if the first checkbox block is selected', function () {
        var expectedOutput = 'Selected';
        var output = FieldsPanelDisplayUtils.getTextValueFromField(checkboxField);
        expect(output).toBe(expectedOutput);
    });
    it('should return not selected if the first checkbox block is not selected', function () {
        var expectedOutput = 'Not Selected';
        var field = __assign(__assign({}, checkboxField), { blocks: [
                __assign(__assign({}, checkboxField.blocks[0]), { text: 'NOT_SELECTED' })
            ] });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
    it('should return empty for an unlabeled field', function () {
        var expectedOutput = DocumentLabelerConstants.EMPTY;
        var field = __assign(__assign({}, checkboxField), { blocks: [] });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
    /** Checkbox Field Tests */
    it('should return the text override value if a text override is specified', function () {
        var override = 'Override';
        var field = __assign(__assign({}, signatureField), { textOverride: override });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(override);
    });
    it('should return region selected if a region is selected', function () {
        var expectedOutput = DocumentLabelerConstants.REGION_SELECTED;
        var output = FieldsPanelDisplayUtils.getTextValueFromField(signatureField);
        expect(output).toBe(expectedOutput);
    });
    it('should return empty for an unlabeled field', function () {
        var expectedOutput = DocumentLabelerConstants.EMPTY;
        var field = __assign(__assign({}, signatureField), { region: undefined });
        var output = FieldsPanelDisplayUtils.getTextValueFromField(field);
        expect(output).toBe(expectedOutput);
    });
});
var table = MockDocumentLabelerData.labels.tables[0];
describe('getTextValueFromTable', function () {
    it('should work correctly for 0 rows', function () {
        var expectedOutput = '0 rows';
        var updatedTable = __assign(__assign({}, table), { rows: [] });
        var output = FieldsPanelDisplayUtils.getTextValueFromTable(updatedTable);
        expect(output).toBe(expectedOutput);
    });
    it('should work correctly for 1 row', function () {
        var expectedOutput = '1 row';
        var output = FieldsPanelDisplayUtils.getTextValueFromTable(table);
        expect(output).toBe(expectedOutput);
    });
    it('should work correctly for many rows', function () {
        var expectedOutput = '5 rows';
        var updatedTable = __assign(__assign({}, table), { rows: Array(5).map(function () { return table.rows[0]; }) });
        var output = FieldsPanelDisplayUtils.getTextValueFromTable(updatedTable);
        expect(output).toBe(expectedOutput);
    });
});
