import { RectCoords } from "documentLabeler/components/documentPanel/documentBlockLayer/utils/EndUserBlockRenderUtils";
import { ActiveField, DocumentLabelerInternalState, LabelingSelectionType } from "documentLabeler/state/DocumentLabelerState";
import { BlockDto, BoundingBoxDto, FieldType } from "common/types/DocumentLabelerTypes";
export declare type FieldColoredBlock = {
    color: string;
    block: BlockDto;
    sourceFieldId: string;
    sourceFieldType: FieldType;
};
export declare type CellColoredBlock = {
    color: string;
    block: BlockDto;
    tableId: string;
    rowId: string;
    columnId: string;
    sourceFieldType: FieldType.Table;
};
export declare type ColoredBlockType = FieldColoredBlock | CellColoredBlock;
declare type RegionFieldColoredBlock = {
    id: string;
    color: string;
    region: BoundingBoxDto;
    sourceFieldId: string;
    sourceFieldType: FieldType;
};
declare type RegionCellColoredBlock = RegionFieldColoredBlock & {
    tableId: string;
    rowId: string;
    columnId: string;
};
export declare type RegionColoredBlock = RegionFieldColoredBlock | RegionCellColoredBlock;
export declare const BlockUtils: {
    isTextOrCheckBoxBlock: (block: ColoredBlockType) => block is FieldColoredBlock;
    isCellLabel: (block: ColoredBlockType | RegionColoredBlock) => block is CellColoredBlock;
    isActiveCellBlock: (coloredBlock: CellColoredBlock, selectedField?: ActiveField) => boolean;
    getColoredBlockOpacity: (coloredBlock: ColoredBlockType | RegionColoredBlock, selectedField?: ActiveField) => number;
    sortBlocks: (blocks: Array<BlockDto>) => Array<BlockDto>;
    getRegionFromRectangle: (rectangle: RectCoords, pageWidth: number, docPageHeights: Array<number>) => BoundingBoxDto;
    getColoredRegions: (state: DocumentLabelerInternalState) => Array<RegionColoredBlock>;
    getColoredRegionsToDisplay: (state: DocumentLabelerInternalState, regions: Array<RegionColoredBlock>) => Array<RegionColoredBlock>;
    getColoredBlocks: (state: DocumentLabelerInternalState) => Array<ColoredBlockType>;
    getColoredBlocksToDisplay: (state: DocumentLabelerInternalState, coloredBlocks: Array<ColoredBlockType>) => Array<ColoredBlockType>;
    getFilteredUnhighlightedBlocks: (selectedField: ActiveField | undefined, coloredBlocks: Array<ColoredBlockType>, wordBlocks: Array<BlockDto>, selectionType: LabelingSelectionType) => Array<BlockDto>;
    getActiveRegion: (state: DocumentLabelerInternalState, regionsToDisplay: Array<RegionColoredBlock>) => BoundingBoxDto | undefined;
};
export {};
