import { RegionColoredBlock } from "documentLabeler/components/documentPanel/documentBlockLayer/utils/BlockUtils";
import { BlockDto, BoundingBoxDto } from "common/types/DocumentLabelerTypes";
declare type DomRectangle = {
    left: number;
    top: number;
    height: number;
    width: number;
};
export declare type Coords = {
    x: number;
    y: number;
};
/**
 * Represents the coordinates of a rectangle.
 * start corresponds to the top left and end
 * corresponds to the bottom right.
 */
export declare type RectCoords = {
    start: Coords;
    end: Coords;
};
declare type MinMaxRect = {
    minX: number;
    maxX: number;
    minY: number;
    maxY: number;
};
/**
 * Utility functions used to help determine which blocks
 * should be rendered on the End User Block Layer
 */
export declare const EndUserBlockRenderUtils: {
    getBlockRenderCoords: (boundingBox: BoundingBoxDto, docPageHeights: Array<number>, docRenderWidth: number) => DomRectangle;
    getBlocksUnderMouse: (blocks: Array<BlockDto>, mouseCoordinates: {
        x: number;
        y: number;
    }, docPageHeights: Array<number>, docRenderWidth: number) => Array<BlockDto>;
    getRegionsUnderMouse: (regions: Array<RegionColoredBlock>, mouseCoordinates: {
        x: number;
        y: number;
    }, docPageHeights: Array<number>, docRenderWidth: number) => Array<RegionColoredBlock>;
    getWordBlocksInsideRectangle: (rectCoords: RectCoords, wordBlocks: Array<BlockDto>, docPageHeights: Array<number>, docRenderWidth: number) => Array<BlockDto>;
    convertEventCoordsToRefSpace: (ref: React.RefObject<HTMLDivElement>, evt: React.MouseEvent) => Coords;
    toMinMax: (rect: RectCoords) => MinMaxRect;
    doRectanglesIntersect: (rectA: RectCoords, rectB: RectCoords) => boolean;
    convertBoundingBoxToRectCoords: (boundingBox: DomRectangle) => RectCoords;
};
export {};
