var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { alpha, Box, Button, IconButton, makeStyles } from '@material-ui/core';
import { Close, Create } from '@material-ui/icons';
import { OutlinedTextField } from 'common/display/OutlinedTextField/OutlinedTextField';
import { TruncatableTypography } from 'common/display/TruncatableTypography/TruncatableTypography';
import { useDocumentLabeler } from 'documentLabeler/DocumentLabelerProvider';
import { FieldType } from 'common/types/DocumentLabelerTypes';
import { useState } from 'react';
import clsx from 'clsx';
var SAVE = 'Save';
var EMPTY_VALUE = 'No Value Specified';
var useStyles = makeStyles(function (theme) { return ({
    Root: {
        display: 'flex',
        gap: theme.spacing(1),
        padding: theme.spacing(1),
        paddingLeft: theme.spacing(2),
        cursor: 'pointer',
        justifyContent: 'space-between',
        height: theme.spacing(6),
    },
    TopRowContainer: {
        display: 'flex',
        alignItems: 'center',
    },
    FieldIconContainer: {
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        padding: theme.spacing(1),
        paddingLeft: 0,
    },
    FieldInfoContainer: {
        flex: 1,
        minWidth: 0,
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-around',
    },
    FieldActionContainer: {
        display: 'flex',
        alignItems: 'flex-end',
    },
    FieldLabelTypography: {
        color: theme.palette.text.disabled,
    },
    FieldValueTypography: {
        color: theme.palette.text.secondary,
        '&.Disabled': {
            color: theme.palette.text.disabled,
        },
    },
    IconButton: {
        padding: 0,
        marginRight: theme.spacing(1),
        '&.Hide': {
            opacity: 0,
            pointerEvents: 'none',
        },
    },
}); });
/**
 * Component responsible for rendering a field in the fields panel.
 * Takes in information about the field and its associated display color
 * and handles selecting the field and editing the field value.
 * @param Props
 */
export var FieldsPanelDisplayRow = function (_a) {
    var _b;
    var id = _a.id, type = _a.type, name = _a.name, value = _a.value, color = _a.color, _c = _a.hasValue, hasValue = _c === void 0 ? true : _c;
    var classes = useStyles();
    var _d = useDocumentLabeler(), state = _d.state, dispatch = _d.dispatch;
    var _e = useState(false), editingText = _e[0], setEditingText = _e[1];
    var _f = useState(value), localValue = _f[0], setLocalValue = _f[1];
    var fieldIsActive = ((_b = state.localState.activeField) === null || _b === void 0 ? void 0 : _b.id) === id;
    var handleFieldClick = function () {
        if (fieldIsActive) {
            dispatch({
                type: 'setActiveField',
                payload: undefined,
            });
        }
        else {
            dispatch({
                type: 'setActiveField',
                payload: {
                    id: id,
                    type: type,
                },
            });
        }
    };
    var handleClearLabels = function () { return dispatch({
        type: 'removeAllBlocksFromField',
        payload: {
            fieldId: id,
            fieldType: type,
        }
    }); };
    var handleSaveValue = function () {
        dispatch({
            type: 'setFieldTextOverride',
            payload: {
                fieldId: id,
                textOverride: localValue,
            }
        });
        setEditingText(false);
    };
    return (_jsxs(Box, __assign({ className: classes.Root, onClick: handleFieldClick, style: {
            borderLeft: "4px solid ".concat(color),
            backgroundColor: fieldIsActive
                ? alpha(color, 0.1)
                : 'transparent',
        } }, { children: [_jsx(Box, __assign({ className: classes.FieldInfoContainer }, { children: editingText ? (_jsx(OutlinedTextField, { value: localValue, placeholder: EMPTY_VALUE, onChange: function (e) { return setLocalValue(e.target.value); } })) : (_jsxs(_Fragment, { children: [_jsx(Box, __assign({ className: classes.TopRowContainer }, { children: _jsx(TruncatableTypography, { value: name, paragraph: false, typographyProps: {
                                    variant: 'caption',
                                    className: classes.FieldLabelTypography,
                                } }) })), _jsx(TruncatableTypography, { value: value, paragraph: false, typographyProps: {
                                variant: 'subtitle2'
                            } })] })) })), editingText ? (_jsx(Button, __assign({ variant: 'text', color: 'primary', onClick: function (event) {
                    event.stopPropagation();
                    handleSaveValue();
                } }, { children: SAVE }))) : (_jsxs(Box, __assign({ className: classes.FieldActionContainer }, { children: [_jsx(IconButton, __assign({ className: clsx(classes.IconButton, {
                            Hide: type === FieldType.Table,
                        }), onClick: function (event) {
                            event.stopPropagation();
                            setLocalValue(value);
                            setEditingText(true);
                        } }, { children: _jsx(Create, { fontSize: 'small' }) })), _jsx(IconButton, __assign({ className: clsx(classes.IconButton, {
                            Hide: !hasValue,
                        }), onClick: function (event) {
                            event.stopPropagation();
                            handleClearLabels();
                        } }, { children: _jsx(Close, { fontSize: 'small' }) }))] })))] })));
};
