var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { FieldsPanelUtils } from "documentLabeler/components/fieldsPanel/util/FieldsPanelUtils";
import { MockDocumentLabelerData } from "documentLabeler/MockDocumentLabelerData.stories";
var textField = MockDocumentLabelerData.labels.fields[0];
var checkboxField = MockDocumentLabelerData.labels.fields[2];
var signatureField = MockDocumentLabelerData.labels.fields[3];
describe('fieldHasLabeledValue', function () {
    /** Text Field Tests */
    it('should return true for a field with blocks', function () {
        var output = FieldsPanelUtils.fieldHasLabeledValue(textField);
        expect(output).toBe(true);
    });
    it('should return true for a field with a selected region', function () {
        var regionLabeledTextField = __assign(__assign({}, textField), { blocks: [], region: signatureField.region });
        var output = FieldsPanelUtils.fieldHasLabeledValue(regionLabeledTextField);
        expect(output).toBe(true);
    });
    it('should return true for a field with a text override', function () {
        var textOverrideTextField = __assign(__assign({}, textField), { blocks: [], textOverride: 'overridden!' });
        var output = FieldsPanelUtils.fieldHasLabeledValue(textOverrideTextField);
        expect(output).toBe(true);
    });
    it('should return false for an unlabeled field', function () {
        var unlabeledTextField = __assign(__assign({}, textField), { blocks: [], region: undefined, textOverride: undefined });
        var output = FieldsPanelUtils.fieldHasLabeledValue(unlabeledTextField);
        expect(output).toBe(false);
    });
    /** Checkbox Field Tests */
    it('should return true for a field with blocks', function () {
        var output = FieldsPanelUtils.fieldHasLabeledValue(checkboxField);
        expect(output).toBe(true);
    });
    it('should return true for a field with a selected region', function () {
        var regionLabeledCheckboxField = __assign(__assign({}, checkboxField), { blocks: [], region: signatureField.region });
        var output = FieldsPanelUtils.fieldHasLabeledValue(regionLabeledCheckboxField);
        expect(output).toBe(true);
    });
    it('should return true for a field with a text override', function () {
        var textOverrideCheckboxField = __assign(__assign({}, checkboxField), { blocks: [], textOverride: 'overridden!' });
        var output = FieldsPanelUtils.fieldHasLabeledValue(textOverrideCheckboxField);
        expect(output).toBe(true);
    });
    it('should return false for an unlabeled field', function () {
        var unlabeledCheckboxField = __assign(__assign({}, checkboxField), { blocks: [], region: undefined, textOverride: undefined });
        var output = FieldsPanelUtils.fieldHasLabeledValue(unlabeledCheckboxField);
        expect(output).toBe(false);
    });
    /** Signature Field Tests */
    it('should return true for a field with a selected region', function () {
        var output = FieldsPanelUtils.fieldHasLabeledValue(signatureField);
        expect(output).toBe(true);
    });
    it('should return true for a field with a text override', function () {
        var textOverrideSignatureField = __assign(__assign({}, signatureField), { region: undefined, textOverride: 'overridden!' });
        var output = FieldsPanelUtils.fieldHasLabeledValue(textOverrideSignatureField);
        expect(output).toBe(true);
    });
    it('should return false for an unlabeled field', function () {
        var unlabeledSignatureField = __assign(__assign({}, signatureField), { blocks: [], region: undefined, textOverride: undefined });
        var output = FieldsPanelUtils.fieldHasLabeledValue(unlabeledSignatureField);
        expect(output).toBe(false);
    });
});
var table = MockDocumentLabelerData.labels.tables[0];
describe('tableHasLabeledValue', function () {
    it('should return true for a table with rows', function () {
        var output = FieldsPanelUtils.tableHasLabeledValue(table);
        expect(output).toBe(true);
    });
    it('should return false for a table with no rows', function () {
        var unlabeledTable = __assign(__assign({}, table), { rows: [] });
        var output = FieldsPanelUtils.tableHasLabeledValue(unlabeledTable);
        expect(output).toBe(false);
    });
});
